@@ -290,7 +290,7 @@ def bExecuteWinScp(winscpExe, keyFile, server, commandAry, showCmd=False):
     cmd = f'{winscpExe} /log={logFile} /loglevel=0 /command ' + ' '.join('"%s"' % x for x in ary)
     if showCmd:
         bInfo(cmd)
-    bExecute(cmd)
+    return bExecute(cmd)
 
 
 def bZipFile(toFile, fileFolderOrAry, rename=None):
